@@ -224,7 +224,7 @@ get_dnskeys(ksr_ctx_t *ksr, dns_dnsseckeylist_t *keys) {
 	ISC_LIST_INIT(*keys);
 	ISC_LIST_INIT(keys_read);
 	ret = dns_dnssec_findmatchingkeys(name, NULL, ksr->keydir, NULL,
-					  ksr->now, mctx, &keys_read);
+					  ksr->now, false, mctx, &keys_read);
 	if (ret != ISC_R_SUCCESS && ret != ISC_R_NOTFOUND) {
 		fatal("failed to load existing keys from %s: %s", ksr->keydir,
 		      isc_result_totext(ret));
@@ -1012,10 +1012,11 @@ parse_dnskey(isc_lex_t *lex, char *owner, isc_buffer_t *buf, dns_ttl_t *ttl) {
 	isc_buffer_add(&b, strlen(owner));
 	ret = dns_name_fromtext(dname, &b, dns_rootname, 0, NULL);
 	if (ret != ISC_R_SUCCESS) {
-		return ret;
+		goto cleanup;
 	}
 	if (dns_name_compare(dname, name) != 0) {
-		return DNS_R_BADOWNERNAME;
+		ret = DNS_R_BADOWNERNAME;
+		goto cleanup;
 	}
 	isc_buffer_clear(&b);
 
