@@ -23,14 +23,14 @@ echo_i "ns1/sign.sh"
 
 cp $infile $zonefile
 
-if [ -f ../ed25519-supported.file ]; then
+if [ $ED25519_SUPPORTED = 1 ]; then
   zsk25519=$($KEYGEN -q -a ED25519 -n zone "$zone")
   ksk25519=$($KEYGEN -q -a ED25519 -n zone -f KSK "$zone")
   cat "$ksk25519.key" "$zsk25519.key" >>"$zonefile"
   $DSFROMKEY -a sha-256 "$ksk25519.key" >>dsset-256
 fi
 
-if [ -f ../ed448-supported.file ]; then
+if [ $ED448_SUPPORTED = 1 ]; then
   zsk448=$($KEYGEN -q -a ED448 -n zone "$zone")
   ksk448=$($KEYGEN -q -a ED448 -n zone -f KSK "$zone")
   cat "$ksk448.key" "$zsk448.key" >>"$zonefile"
@@ -38,7 +38,7 @@ if [ -f ../ed448-supported.file ]; then
 fi
 
 # Configure the resolving server with a static key.
-if [ -f ../ed25519-supported.file ]; then
+if [ $ED25519_SUPPORTED = 1 ]; then
   keyfile_to_static_ds $ksk25519 >trusted.conf
   cp trusted.conf ../ns2/trusted.conf
 else
@@ -46,7 +46,7 @@ else
   cp trusted.conf ../ns2/trusted.conf
 fi
 
-if [ -f ../ed448-supported.file ]; then
+if [ $ED448_SUPPORTED = 1 ]; then
   keyfile_to_static_ds $ksk448 >trusted.conf
   cp trusted.conf ../ns3/trusted.conf
 else
