@@ -11,6 +11,9 @@
 
 import pytest
 
+# isctest.asyncserver requires dnspython >= 2.0.0
+pytest.importorskip("dns", minversion="2.0.0")
+
 pytestmark = pytest.mark.extra_artifacts(
     [
         "dig.out.*",
@@ -22,9 +25,7 @@ pytestmark = pytest.mark.extra_artifacts(
     ]
 )
 
-import isctest.mark
 
-
-@isctest.mark.flaky(max_runs=2)
+@pytest.mark.flaky(max_runs=3)
 def test_fetchlimit(run_tests_sh):
     run_tests_sh()
