@@ -9,6 +9,20 @@
 # See the COPYRIGHT file distributed with this work for additional
 # information regarding copyright ownership.
 
+import pytest
+
+pytestmark = pytest.mark.extra_artifacts(
+    [
+        "dig.out.*",
+        "journalprint.out.*",
+        "tmp.jnl",
+        "ns*/*.db",
+        "ns*/*.jnl",
+        "ns1/managed-keys.bind",
+        "ns2/managed-keys.bind",
+    ]
+)
+
 
 def test_journal(run_tests_sh):
     run_tests_sh()
