@@ -11,12 +11,14 @@
 
 import pytest
 
+# isctest.asyncserver requires dnspython >= 2.0.0
+pytest.importorskip("dns", minversion="2.0.0")
+
 pytestmark = pytest.mark.extra_artifacts(
     [
         "dig.out.*",
         "dnsrps.cache",
-        "dnsrps*.conf",
-        "dnsrpzd*",
+        "dnsrps.conf",
         "ans*/ans.run",
         "ns2/*.queries",
         "ns2/*.local",
