@@ -11,6 +11,9 @@
 
 import pytest
 
+# isctest.asyncserver requires dnspython >= 2.0.0
+pytest.importorskip("dns", minversion="2.0.0")
+
 pytestmark = pytest.mark.extra_artifacts(
     [
         "curl.out.*",
@@ -20,7 +23,6 @@ pytestmark = pytest.mark.extra_artifacts(
         "xsltproc.out.*",
         "ans*/ans.run",
         "ns*/statistics-channels.conf",
-        "ns*/named.recursing",
     ]
 )
 
