@@ -27,12 +27,11 @@ static isc_mem_t *mctx = NULL;
 static isc_lex_t *lex = NULL;
 
 int
-LLVMFuzzerInitialize(int *argc __attribute__((unused)),
-		     char ***argv __attribute__((unused))) {
+LLVMFuzzerInitialize(int *argc ISC_ATTR_UNUSED, char ***argv ISC_ATTR_UNUSED) {
 	isc_mem_create(&mctx);
 	isc_lex_create(mctx, 1024, &lex);
 
-	return (0);
+	return 0;
 }
 
 int
@@ -51,5 +50,5 @@ LLVMFuzzerTestOneInput(const uint8_t *data, size_t size) {
 		result = isc_lex_gettoken(lex, 0, &token);
 	} while (result == ISC_R_SUCCESS);
 
-	return (0);
+	return 0;
 }
