@@ -15,6 +15,7 @@
 
 #include <inttypes.h>
 #include <stdbool.h>
+#include <stddef.h>
 #include <stdlib.h>
 
 #include <isc/buffer.h>
@@ -47,8 +48,7 @@
 
 static dns_rdatatype_t
 rdata_covers(dns_rdata_t *rdata) {
-	return (rdata->type == dns_rdatatype_rrsig ? dns_rdata_covers(rdata)
-						   : 0);
+	return rdata->type == dns_rdatatype_rrsig ? dns_rdata_covers(rdata) : 0;
 }
 
 isc_result_t
@@ -99,7 +99,7 @@ dns_difftuple_create(isc_mem_t *mctx, dns_diffop_t op, const dns_name_t *name,
 	INSIST(datap == (unsigned char *)t + size);
 
 	*tp = t;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 void
@@ -119,8 +119,8 @@ dns_difftuple_free(dns_difftuple_t **tp) {
 
 isc_result_t
 dns_difftuple_copy(dns_difftuple_t *orig, dns_difftuple_t **copyp) {
-	return (dns_difftuple_create(orig->mctx, orig->op, &orig->name,
-				     orig->ttl, &orig->rdata, copyp));
+	return dns_difftuple_create(orig->mctx, orig->op, &orig->name,
+				    orig->ttl, &orig->rdata, copyp);
 }
 
 void
@@ -128,6 +128,7 @@ dns_diff_init(isc_mem_t *mctx, dns_diff_t *diff) {
 	diff->mctx = mctx;
 	ISC_LIST_INIT(diff->tuples);
 	diff->magic = DNS_DIFF_MAGIC;
+	diff->size = 0;
 }
 
 void
@@ -138,15 +139,37 @@ dns_diff_clear(dns_diff_t *diff) {
 		ISC_LIST_UNLINK(diff->tuples, t, link);
 		dns_difftuple_free(&t);
 	}
+	diff->size = 0;
 	ENSURE(ISC_LIST_EMPTY(diff->tuples));
 }
 
 void
 dns_diff_append(dns_diff_t *diff, dns_difftuple_t **tuplep) {
+	REQUIRE(DNS_DIFF_VALID(diff));
 	ISC_LIST_APPEND(diff->tuples, *tuplep, link);
+	diff->size += 1;
 	*tuplep = NULL;
 }
 
+bool
+dns_diff_is_boundary(const dns_diff_t *diff, dns_name_t *new_name) {
+	REQUIRE(DNS_DIFF_VALID(diff));
+	REQUIRE(DNS_NAME_VALID(new_name));
+
+	if (ISC_LIST_EMPTY(diff->tuples)) {
+		return false;
+	}
+
+	dns_difftuple_t *tail = ISC_LIST_TAIL(diff->tuples);
+	return !dns_name_caseequal(&tail->name, new_name);
+}
+
+size_t
+dns_diff_size(const dns_diff_t *diff) {
+	REQUIRE(DNS_DIFF_VALID(diff));
+	return diff->size;
+}
+
 /* XXX this is O(N) */
 
 void
@@ -175,6 +198,9 @@ dns_diff_appendminimal(dns_diff_t *diff, dns_difftuple_t **tuplep) {
 		    ot->ttl == (*tuplep)->ttl)
 		{
 			ISC_LIST_UNLINK(diff->tuples, ot, link);
+			INSIST(diff->size > 0);
+			diff->size -= 1;
+
 			if ((*tuplep)->op == ot->op) {
 				UNEXPECTED_ERROR("unexpected non-minimal diff");
 			} else {
@@ -187,6 +213,7 @@ dns_diff_appendminimal(dns_diff_t *diff, dns_difftuple_t **tuplep) {
 
 	if (*tuplep != NULL) {
 		ISC_LIST_APPEND(diff->tuples, *tuplep, link);
+		diff->size += 1;
 		*tuplep = NULL;
 	}
 }
@@ -224,7 +251,7 @@ setresign(dns_rdataset_t *modified) {
 		result = dns_rdataset_next(modified);
 	}
 	INSIST(result == ISC_R_NOMORE);
-	return ((isc_stdtime_t)when);
+	return (isc_stdtime_t)when;
 }
 
 static void
@@ -245,20 +272,21 @@ static const char *
 optotext(dns_diffop_t op) {
 	switch (op) {
 	case DNS_DIFFOP_ADD:
-		return ("add");
+		return "add";
 	case DNS_DIFFOP_ADDRESIGN:
-		return ("add-resign");
+		return "add-resign";
 	case DNS_DIFFOP_DEL:
-		return ("del");
+		return "del";
 	case DNS_DIFFOP_DELRESIGN:
-		return ("del-resign");
+		return "del-resign";
 	default:
-		return ("unknown");
+		return "unknown";
 	}
 }
 
 static isc_result_t
-diff_apply(dns_diff_t *diff, dns_db_t *db, dns_dbversion_t *ver, bool warn) {
+diff_apply(const dns_diff_t *diff, dns_db_t *db, dns_dbversion_t *ver,
+	   bool warn) {
 	dns_difftuple_t *t;
 	dns_dbnode_t *node = NULL;
 	isc_result_t result;
@@ -485,29 +513,30 @@ diff_apply(dns_diff_t *diff, dns_db_t *db, dns_dbversion_t *ver, bool warn) {
 			}
 		}
 	}
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 failure:
 	if (node != NULL) {
 		dns_db_detachnode(db, &node);
 	}
-	return (result);
+	return result;
 }
 
 isc_result_t
-dns_diff_apply(dns_diff_t *diff, dns_db_t *db, dns_dbversion_t *ver) {
-	return (diff_apply(diff, db, ver, true));
+dns_diff_apply(const dns_diff_t *diff, dns_db_t *db, dns_dbversion_t *ver) {
+	return diff_apply(diff, db, ver, true);
 }
 
 isc_result_t
-dns_diff_applysilently(dns_diff_t *diff, dns_db_t *db, dns_dbversion_t *ver) {
-	return (diff_apply(diff, db, ver, false));
+dns_diff_applysilently(const dns_diff_t *diff, dns_db_t *db,
+		       dns_dbversion_t *ver) {
+	return diff_apply(diff, db, ver, false);
 }
 
 /* XXX this duplicates lots of code in diff_apply(). */
 
 isc_result_t
-dns_diff_load(dns_diff_t *diff, dns_rdatacallbacks_t *callbacks) {
+dns_diff_load(const dns_diff_t *diff, dns_rdatacallbacks_t *callbacks) {
 	dns_difftuple_t *t;
 	isc_result_t result;
 
@@ -579,7 +608,7 @@ failure:
 	if (callbacks->commit != NULL) {
 		callbacks->commit(callbacks->add_private);
 	}
-	return (result);
+	return result;
 }
 
 /*
@@ -600,7 +629,7 @@ dns_diff_sort(dns_diff_t *diff, dns_diff_compare_func *compare) {
 		length++;
 	}
 	if (length == 0) {
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 	v = isc_mem_cget(diff->mctx, length, sizeof(dns_difftuple_t *));
 	for (i = 0; i < length; i++) {
@@ -614,7 +643,7 @@ dns_diff_sort(dns_diff_t *diff, dns_diff_compare_func *compare) {
 		ISC_LIST_APPEND(diff->tuples, v[i], link);
 	}
 	isc_mem_cput(diff->mctx, v, length, sizeof(dns_difftuple_t *));
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 /*
@@ -642,7 +671,7 @@ diff_tuple_tordataset(dns_difftuple_t *t, dns_rdata_t *rdata,
 }
 
 isc_result_t
-dns_diff_print(dns_diff_t *diff, FILE *file) {
+dns_diff_print(const dns_diff_t *diff, FILE *file) {
 	isc_result_t result;
 	dns_difftuple_t *t;
 	char *mem = NULL;
@@ -651,66 +680,74 @@ dns_diff_print(dns_diff_t *diff, FILE *file) {
 
 	REQUIRE(DNS_DIFF_VALID(diff));
 
-	mem = isc_mem_get(diff->mctx, size);
+	int required_log_level = ISC_LOG_DEBUG(7);
 
-	for (t = ISC_LIST_HEAD(diff->tuples); t != NULL;
-	     t = ISC_LIST_NEXT(t, link))
-	{
-		isc_buffer_t buf;
-		isc_region_t r;
+	/*
+	 * Logging requires allocating a buffer and some costly translation to
+	 * text. Avoid it if possible.
+	 */
+	if (isc_log_wouldlog(dns_lctx, required_log_level) || file != NULL) {
+		mem = isc_mem_get(diff->mctx, size);
 
-		dns_rdatalist_t rdl;
-		dns_rdataset_t rds;
-		dns_rdata_t rd = DNS_RDATA_INIT;
+		for (t = ISC_LIST_HEAD(diff->tuples); t != NULL;
+		     t = ISC_LIST_NEXT(t, link))
+		{
+			isc_buffer_t buf;
+			isc_region_t r;
 
-		diff_tuple_tordataset(t, &rd, &rdl, &rds);
-	again:
-		isc_buffer_init(&buf, mem, size);
-		result = dns_rdataset_totext(&rds, &t->name, false, false,
-					     &buf);
+			dns_rdatalist_t rdl;
+			dns_rdataset_t rds;
+			dns_rdata_t rd = DNS_RDATA_INIT;
 
-		if (result == ISC_R_NOSPACE) {
-			isc_mem_put(diff->mctx, mem, size);
-			size += 1024;
-			mem = isc_mem_get(diff->mctx, size);
-			goto again;
-		}
+			diff_tuple_tordataset(t, &rd, &rdl, &rds);
+		again:
+			isc_buffer_init(&buf, mem, size);
+			result = dns_rdataset_totext(&rds, &t->name, false,
+						     false, &buf);
 
-		if (result != ISC_R_SUCCESS) {
-			goto cleanup;
-		}
-		/*
-		 * Get rid of final newline.
-		 */
-		INSIST(buf.used >= 1 &&
-		       ((char *)buf.base)[buf.used - 1] == '\n');
-		buf.used--;
+			if (result == ISC_R_NOSPACE) {
+				isc_mem_put(diff->mctx, mem, size);
+				size += 1024;
+				mem = isc_mem_get(diff->mctx, size);
+				goto again;
+			}
 
-		isc_buffer_usedregion(&buf, &r);
-		switch (t->op) {
-		case DNS_DIFFOP_EXISTS:
-			op = "exists";
-			break;
-		case DNS_DIFFOP_ADD:
-			op = "add";
-			break;
-		case DNS_DIFFOP_DEL:
-			op = "del";
-			break;
-		case DNS_DIFFOP_ADDRESIGN:
-			op = "add re-sign";
-			break;
-		case DNS_DIFFOP_DELRESIGN:
-			op = "del re-sign";
-			break;
-		}
-		if (file != NULL) {
-			fprintf(file, "%s %.*s\n", op, (int)r.length,
-				(char *)r.base);
-		} else {
-			isc_log_write(DIFF_COMMON_LOGARGS, ISC_LOG_DEBUG(7),
-				      "%s %.*s", op, (int)r.length,
-				      (char *)r.base);
+			if (result != ISC_R_SUCCESS) {
+				goto cleanup;
+			}
+			/*
+			 * Get rid of final newline.
+			 */
+			INSIST(buf.used >= 1 &&
+			       ((char *)buf.base)[buf.used - 1] == '\n');
+			buf.used--;
+
+			isc_buffer_usedregion(&buf, &r);
+			switch (t->op) {
+			case DNS_DIFFOP_EXISTS:
+				op = "exists";
+				break;
+			case DNS_DIFFOP_ADD:
+				op = "add";
+				break;
+			case DNS_DIFFOP_DEL:
+				op = "del";
+				break;
+			case DNS_DIFFOP_ADDRESIGN:
+				op = "add re-sign";
+				break;
+			case DNS_DIFFOP_DELRESIGN:
+				op = "del re-sign";
+				break;
+			}
+			if (file != NULL) {
+				fprintf(file, "%s %.*s\n", op, (int)r.length,
+					(char *)r.base);
+			} else {
+				isc_log_write(DIFF_COMMON_LOGARGS,
+					      required_log_level, "%s %.*s", op,
+					      (int)r.length, (char *)r.base);
+			}
 		}
 	}
 	result = ISC_R_SUCCESS;
@@ -718,5 +755,5 @@ cleanup:
 	if (mem != NULL) {
 		isc_mem_put(diff->mctx, mem, size);
 	}
-	return (result);
+	return result;
 }
