@@ -409,7 +409,7 @@ dns_dnssec_verify(const dns_name_t *name, dns_rdataset_t *set, dst_key_t *key,
 	}
 
 	/*
-	 * NS, SOA and DNSSKEY records are signed by their owner.
+	 * NS, SOA and DNSKEY records are signed by their owner.
 	 * DS records are signed by the parent.
 	 */
 	switch (set->type) {
@@ -1199,13 +1199,13 @@ dns_dnssec_get_hints(dns_dnsseckey_t *key, isc_stdtime_t now) {
 }
 
 static isc_result_t
-findmatchingkeys(const char *directory, char *namebuf, unsigned int len,
-		 isc_mem_t *mctx, isc_stdtime_t now,
+findmatchingkeys(const char *directory, bool rrtypekey, char *namebuf,
+		 unsigned int len, isc_mem_t *mctx, isc_stdtime_t now,
 		 dns_dnsseckeylist_t *list) {
-	isc_result_t result = ISC_R_SUCCESS;
+	isc_result_t result;
 	isc_dir_t dir;
-	bool dir_open = false;
-	unsigned int i, alg;
+	bool dir_open = false, match = false;
+	unsigned int i;
 	dns_dnsseckey_t *key = NULL;
 	dst_key_t *dstkey = NULL;
 
@@ -1213,6 +1213,7 @@ findmatchingkeys(const char *directory, char *namebuf, unsigned int len,
 	if (directory == NULL) {
 		directory = ".";
 	}
+
 	RETERR(isc_dir_open(&dir, directory));
 	dir_open = true;
 
@@ -1224,13 +1225,10 @@ findmatchingkeys(const char *directory, char *namebuf, unsigned int len,
 			continue;
 		}
 
-		alg = 0;
 		for (i = len + 1 + 1; i < dir.entry.length; i++) {
 			if (!isdigit((unsigned char)dir.entry.name[i])) {
 				break;
 			}
-			alg *= 10;
-			alg += dir.entry.name[i] - '0';
 		}
 
 		/*
@@ -1261,24 +1259,16 @@ findmatchingkeys(const char *directory, char *namebuf, unsigned int len,
 			continue;
 		}
 
+		int type = DST_TYPE_PUBLIC | DST_TYPE_PRIVATE | DST_TYPE_STATE;
+		if (rrtypekey) {
+			type |= DST_TYPE_KEY;
+		}
 		dstkey = NULL;
-		result = dst_key_fromnamedfile(
-			dir.entry.name, directory,
-			DST_TYPE_PUBLIC | DST_TYPE_PRIVATE | DST_TYPE_STATE,
-			mctx, &dstkey);
-
-		switch (alg) {
-		case DST_ALG_HMACMD5:
-		case DST_ALG_HMACSHA1:
-		case DST_ALG_HMACSHA224:
-		case DST_ALG_HMACSHA256:
-		case DST_ALG_HMACSHA384:
-		case DST_ALG_HMACSHA512:
-			if (result == DST_R_BADKEYTYPE) {
-				continue;
-			}
+		result = dst_key_fromnamedfile(dir.entry.name, directory, type,
+					       mctx, &dstkey);
+		if (result == DST_R_BADKEYTYPE) {
+			continue;
 		}
-
 		if (result != ISC_R_SUCCESS) {
 			isc_log_write(dns_lctx, DNS_LOGCATEGORY_GENERAL,
 				      DNS_LOGMODULE_DNSSEC, ISC_LOG_WARNING,
@@ -1297,9 +1287,11 @@ findmatchingkeys(const char *directory, char *namebuf, unsigned int len,
 			dns_dnsseckey_destroy(mctx, &key);
 		} else {
 			ISC_LIST_APPEND(*list, key, link);
+			match = true;
 			key = NULL;
 		}
 	}
+	result = match ? ISC_R_SUCCESS : ISC_R_NOTFOUND;
 
 failure:
 	if (dir_open) {
@@ -1312,12 +1304,13 @@ failure:
 }
 
 /*%
- * Get a list of DNSSEC keys from the key repository.
+ * Get a list of KEY or DNSKEY keys from the key repository. If rrtypekey
+ * is true KEY keys will be returned otherwise DNSSEC keys.
  */
 isc_result_t
 dns_dnssec_findmatchingkeys(const dns_name_t *origin, dns_kasp_t *kasp,
 			    const char *keydir, dns_keystorelist_t *keystores,
-			    isc_stdtime_t now, isc_mem_t *mctx,
+			    isc_stdtime_t now, bool rrtypekey, isc_mem_t *mctx,
 			    dns_dnsseckeylist_t *keylist) {
 	isc_result_t result = ISC_R_SUCCESS;
 	dns_dnsseckeylist_t list;
@@ -1337,8 +1330,8 @@ dns_dnssec_findmatchingkeys(const dns_name_t *origin, dns_kasp_t *kasp,
 	if (kasp == NULL || (strcmp(dns_kasp_getname(kasp), "none") == 0) ||
 	    (strcmp(dns_kasp_getname(kasp), "insecure") == 0))
 	{
-		RETERR(findmatchingkeys(keydir, namebuf, len, mctx, now,
-					&list));
+		RETERR(findmatchingkeys(keydir, rrtypekey, namebuf, len, mctx,
+					now, &list));
 	} else if (keystores != NULL) {
 		for (dns_keystore_t *keystore = ISC_LIST_HEAD(*keystores);
 		     keystore != NULL; keystore = ISC_LIST_NEXT(keystore, link))
@@ -1352,8 +1345,8 @@ dns_dnssec_findmatchingkeys(const dns_name_t *origin, dns_kasp_t *kasp,
 						dns_keystore_directory(keystore,
 								       keydir);
 					RETERR(findmatchingkeys(
-						directory, namebuf, len, mctx,
-						now, &list));
+						directory, rrtypekey, namebuf,
+						len, mctx, now, &list));
 					break;
 				}
 			}
@@ -1572,7 +1565,7 @@ dns_dnssec_keylistfromrdataset(const dns_name_t *origin, dns_kasp_t *kasp,
 
 		/* Try to read the public key. */
 		result = keyfromfile(kasp, directory, dnskey,
-				     (DST_TYPE_PUBLIC | DST_TYPE_STATE), mctx,
+				     DST_TYPE_PUBLIC | DST_TYPE_STATE, mctx,
 				     &pubkey);
 		if (result == ISC_R_FILENOTFOUND || result == ISC_R_NOPERM) {
 			result = ISC_R_SUCCESS;
@@ -1587,10 +1580,10 @@ dns_dnssec_keylistfromrdataset(const dns_name_t *origin, dns_kasp_t *kasp,
 		}
 
 		/* Now read the private key. */
-		result = keyfromfile(
-			kasp, directory, dnskey,
-			(DST_TYPE_PUBLIC | DST_TYPE_PRIVATE | DST_TYPE_STATE),
-			mctx, &privkey);
+		result = keyfromfile(kasp, directory, dnskey,
+				     DST_TYPE_PUBLIC | DST_TYPE_PRIVATE |
+					     DST_TYPE_STATE,
+				     mctx, &privkey);
 
 		/*
 		 * If the key was revoked and the private file
@@ -1604,9 +1597,9 @@ dns_dnssec_keylistfromrdataset(const dns_name_t *origin, dns_kasp_t *kasp,
 				dst_key_setflags(dnskey,
 						 flags & ~DNS_KEYFLAG_REVOKE);
 				result = keyfromfile(kasp, directory, dnskey,
-						     (DST_TYPE_PUBLIC |
-						      DST_TYPE_PRIVATE |
-						      DST_TYPE_STATE),
+						     DST_TYPE_PUBLIC |
+							     DST_TYPE_PRIVATE |
+							     DST_TYPE_STATE,
 						     mctx, &privkey);
 				if (result == ISC_R_SUCCESS &&
 				    dst_key_pubcompare(dnskey, privkey, false))
@@ -1628,8 +1621,8 @@ dns_dnssec_keylistfromrdataset(const dns_name_t *origin, dns_kasp_t *kasp,
 			result2 = dst_key_getfilename(
 				dst_key_name(dnskey), dst_key_id(dnskey),
 				dst_key_alg(dnskey),
-				(DST_TYPE_PUBLIC | DST_TYPE_PRIVATE |
-				 DST_TYPE_STATE),
+				DST_TYPE_PUBLIC | DST_TYPE_PRIVATE |
+					DST_TYPE_STATE,
 				NULL, mctx, &buf);
 			if (result2 != ISC_R_SUCCESS) {
 				char namebuf[DNS_NAME_FORMATSIZE];
