@@ -14,8 +14,8 @@
 /* */
 #pragma once
 
-typedef struct dns_rdata_l64 {
+typedef struct dns_rdata_l32 {
 	dns_rdatacommon_t common;
 	uint16_t pref;
-	unsigned char l64[8];
-} dns_rdata_l64_t;
+	struct in_addr l32;
+} dns_rdata_l32_t;
