@@ -72,9 +72,9 @@ fromtext_zonemd(ARGS_FROMTEXT) {
 	result = isc_hex_tobuffer(lexer, target, length);
 	/* Minimum length of digest is 12 octets. */
 	if (isc_buffer_usedlength(target) - isc_buffer_usedlength(&save) < 12) {
-		return (ISC_R_UNEXPECTEDEND);
+		return ISC_R_UNEXPECTEDEND;
 	}
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -137,7 +137,7 @@ totext_zonemd(ARGS_TOTEXT) {
 	if ((tctx->flags & DNS_STYLEFLAG_MULTILINE) != 0) {
 		RETERR(str_totext(" )", target));
 	}
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -159,7 +159,7 @@ fromwire_zonemd(ARGS_FROMWIRE) {
 	 * correct length.
 	 */
 	if (sr.length < 18) {
-		return (ISC_R_UNEXPECTEDEND);
+		return ISC_R_UNEXPECTEDEND;
 	}
 
 	switch (sr.base[5]) {
@@ -174,7 +174,7 @@ fromwire_zonemd(ARGS_FROMWIRE) {
 	}
 
 	if (digestlen != 0 && sr.length < 6 + digestlen) {
-		return (ISC_R_UNEXPECTEDEND);
+		return ISC_R_UNEXPECTEDEND;
 	}
 
 	/*
@@ -188,7 +188,7 @@ fromwire_zonemd(ARGS_FROMWIRE) {
 	}
 
 	isc_buffer_forward(source, sr.length);
-	return (mem_tobuffer(target, sr.base, sr.length));
+	return mem_tobuffer(target, sr.base, sr.length);
 }
 
 static isc_result_t
@@ -201,7 +201,7 @@ towire_zonemd(ARGS_TOWIRE) {
 	UNUSED(cctx);
 
 	dns_rdata_toregion(rdata, &sr);
-	return (mem_tobuffer(target, sr.base, sr.length));
+	return mem_tobuffer(target, sr.base, sr.length);
 }
 
 static int
@@ -217,7 +217,7 @@ compare_zonemd(ARGS_COMPARE) {
 
 	dns_rdata_toregion(rdata1, &r1);
 	dns_rdata_toregion(rdata2, &r2);
-	return (isc_region_compare(&r1, &r2));
+	return isc_region_compare(&r1, &r2);
 }
 
 static isc_result_t
@@ -244,7 +244,7 @@ fromstruct_zonemd(ARGS_FROMSTRUCT) {
 	RETERR(uint8_tobuffer(zonemd->scheme, target));
 	RETERR(uint8_tobuffer(zonemd->digest_type, target));
 
-	return (mem_tobuffer(target, zonemd->digest, zonemd->length));
+	return mem_tobuffer(target, zonemd->digest, zonemd->length);
 }
 
 static isc_result_t
@@ -256,9 +256,7 @@ tostruct_zonemd(ARGS_TOSTRUCT) {
 	REQUIRE(zonemd != NULL);
 	REQUIRE(rdata->length != 0);
 
-	zonemd->common.rdclass = rdata->rdclass;
-	zonemd->common.rdtype = rdata->type;
-	ISC_LINK_INIT(&zonemd->common, link);
+	DNS_RDATACOMMON_INIT(zonemd, rdata->type, rdata->rdclass);
 
 	dns_rdata_toregion(rdata, &region);
 
@@ -272,7 +270,7 @@ tostruct_zonemd(ARGS_TOSTRUCT) {
 
 	zonemd->digest = mem_maybedup(mctx, region.base, region.length);
 	zonemd->mctx = mctx;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static void
@@ -301,7 +299,7 @@ additionaldata_zonemd(ARGS_ADDLDATA) {
 	UNUSED(add);
 	UNUSED(arg);
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -312,7 +310,7 @@ digest_zonemd(ARGS_DIGEST) {
 
 	dns_rdata_toregion(rdata, &r);
 
-	return ((digest)(arg, &r));
+	return (digest)(arg, &r);
 }
 
 static bool
@@ -324,7 +322,7 @@ checkowner_zonemd(ARGS_CHECKOWNER) {
 	UNUSED(rdclass);
 	UNUSED(wildcard);
 
-	return (true);
+	return true;
 }
 
 static bool
@@ -335,12 +333,12 @@ checknames_zonemd(ARGS_CHECKNAMES) {
 	UNUSED(owner);
 	UNUSED(bad);
 
-	return (true);
+	return true;
 }
 
 static int
 casecompare_zonemd(ARGS_COMPARE) {
-	return (compare_zonemd(rdata1, rdata2));
+	return compare_zonemd(rdata1, rdata2);
 }
 
 #endif /* RDATA_GENERIC_ZONEMD_63_C */
