@@ -83,7 +83,7 @@ fromtext_in_srv(ARGS_FROMTEXT) {
 	if (!ok && callbacks != NULL) {
 		warn_badname(&name, lexer, callbacks);
 	}
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -136,7 +136,7 @@ totext_in_srv(ARGS_TOTEXT) {
 	dns_name_fromregion(&name, &region);
 	opts = name_prefix(&name, tctx->origin, &prefix) ? DNS_NAME_OMITFINALDOT
 							 : 0;
-	return (dns_name_totext(&prefix, opts, target));
+	return dns_name_totext(&prefix, opts, target);
 }
 
 static isc_result_t
@@ -159,7 +159,7 @@ fromwire_in_srv(ARGS_FROMWIRE) {
 	 */
 	isc_buffer_activeregion(source, &sr);
 	if (sr.length < 6) {
-		return (ISC_R_UNEXPECTEDEND);
+		return ISC_R_UNEXPECTEDEND;
 	}
 	RETERR(mem_tobuffer(target, sr.base, 6));
 	isc_buffer_forward(source, 6);
@@ -167,7 +167,7 @@ fromwire_in_srv(ARGS_FROMWIRE) {
 	/*
 	 * Target.
 	 */
-	return (dns_name_fromwire(&name, source, dctx, target));
+	return dns_name_fromwire(&name, source, dctx, target);
 }
 
 static isc_result_t
@@ -192,7 +192,7 @@ towire_in_srv(ARGS_TOWIRE) {
 	 */
 	dns_name_init(&name, offsets);
 	dns_name_fromregion(&name, &sr);
-	return (dns_name_towire(&name, cctx, target, NULL));
+	return dns_name_towire(&name, cctx, target, NULL);
 }
 
 static int
@@ -215,7 +215,7 @@ compare_in_srv(ARGS_COMPARE) {
 	 */
 	order = memcmp(rdata1->data, rdata2->data, 6);
 	if (order != 0) {
-		return (order < 0 ? -1 : 1);
+		return order < 0 ? -1 : 1;
 	}
 
 	/*
@@ -233,7 +233,7 @@ compare_in_srv(ARGS_COMPARE) {
 	dns_name_fromregion(&name1, &region1);
 	dns_name_fromregion(&name2, &region2);
 
-	return (dns_name_rdatacompare(&name1, &name2));
+	return dns_name_rdatacompare(&name1, &name2);
 }
 
 static isc_result_t
@@ -254,7 +254,7 @@ fromstruct_in_srv(ARGS_FROMSTRUCT) {
 	RETERR(uint16_tobuffer(srv->weight, target));
 	RETERR(uint16_tobuffer(srv->port, target));
 	dns_name_toregion(&srv->target, &region);
-	return (isc_buffer_copyregion(target, &region));
+	return isc_buffer_copyregion(target, &region);
 }
 
 static isc_result_t
@@ -268,9 +268,7 @@ tostruct_in_srv(ARGS_TOSTRUCT) {
 	REQUIRE(srv != NULL);
 	REQUIRE(rdata->length != 0);
 
-	srv->common.rdclass = rdata->rdclass;
-	srv->common.rdtype = rdata->type;
-	ISC_LINK_INIT(&srv->common, link);
+	DNS_RDATACOMMON_INIT(srv, rdata->type, rdata->rdclass);
 
 	dns_name_init(&name, NULL);
 	dns_rdata_toregion(rdata, &region);
@@ -284,7 +282,7 @@ tostruct_in_srv(ARGS_TOSTRUCT) {
 	dns_name_init(&srv->target, NULL);
 	name_duporclone(&name, mctx, &srv->target);
 	srv->mctx = mctx;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static void
@@ -326,12 +324,12 @@ additionaldata_in_srv(ARGS_ADDLDATA) {
 	dns_name_fromregion(&name, &region);
 
 	if (dns_name_equal(&name, dns_rootname)) {
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 
 	result = (add)(arg, &name, dns_rdatatype_a, NULL DNS__DB_FILELINE);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 
 	dns_fixedname_init(&fixed);
@@ -339,17 +337,17 @@ additionaldata_in_srv(ARGS_ADDLDATA) {
 	result = dns_name_fromstring(dns_fixedname_name(&fixed), buf, NULL, 0,
 				     NULL);
 	if (result != ISC_R_SUCCESS) {
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 
 	result = dns_name_concatenate(dns_fixedname_name(&fixed), &name,
 				      dns_fixedname_name(&fixed), NULL);
 	if (result != ISC_R_SUCCESS) {
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 
-	return ((add)(arg, dns_fixedname_name(&fixed), dns_rdatatype_tlsa,
-		      NULL DNS__DB_FILELINE));
+	return (add)(arg, dns_fixedname_name(&fixed), dns_rdatatype_tlsa,
+		     NULL DNS__DB_FILELINE);
 }
 
 static isc_result_t
@@ -367,7 +365,7 @@ digest_in_srv(ARGS_DIGEST) {
 	RETERR((digest)(arg, &r1));
 	dns_name_init(&name, NULL);
 	dns_name_fromregion(&name, &r2);
-	return (dns_name_digest(&name, digest, arg));
+	return dns_name_digest(&name, digest, arg);
 }
 
 static bool
@@ -380,7 +378,7 @@ checkowner_in_srv(ARGS_CHECKOWNER) {
 	UNUSED(rdclass);
 	UNUSED(wildcard);
 
-	return (true);
+	return true;
 }
 
 static bool
@@ -401,14 +399,14 @@ checknames_in_srv(ARGS_CHECKNAMES) {
 		if (bad != NULL) {
 			dns_name_clone(&name, bad);
 		}
-		return (false);
+		return false;
 	}
-	return (true);
+	return true;
 }
 
 static int
 casecompare_in_srv(ARGS_COMPARE) {
-	return (compare_in_srv(rdata1, rdata2));
+	return compare_in_srv(rdata1, rdata2);
 }
 
 #endif /* RDATA_IN_1_SRV_33_C */
