@@ -237,7 +237,7 @@ sdlz_log(int level, const char *fmt, ...) {
 static unsigned int
 initial_size(const char *data) {
 	unsigned int len = (strlen(data) / 64) + 1;
-	return (len * 64 + 64);
+	return len * 64 + 64;
 }
 
 /*
@@ -262,10 +262,10 @@ rdatasetiter_first(dns_rdatasetiter_t *iterator DNS__DB_FLARG) {
 	dns_sdlznode_t *sdlznode = (dns_sdlznode_t *)iterator->node;
 
 	if (ISC_LIST_EMPTY(sdlznode->lists)) {
-		return (ISC_R_NOMORE);
+		return ISC_R_NOMORE;
 	}
 	sdlziterator->current = ISC_LIST_HEAD(sdlznode->lists);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -274,9 +274,9 @@ rdatasetiter_next(dns_rdatasetiter_t *iterator DNS__DB_FLARG) {
 
 	sdlziterator->current = ISC_LIST_NEXT(sdlziterator->current, link);
 	if (sdlziterator->current == NULL) {
-		return (ISC_R_NOMORE);
+		return ISC_R_NOMORE;
 	} else {
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 }
 
@@ -331,7 +331,7 @@ newversion(dns_db_t *db, dns_dbversion_t **versionp) {
 	REQUIRE(VALID_SDLZDB(sdlz));
 
 	if (sdlz->dlzimp->methods->newversion == NULL) {
-		return (ISC_R_NOTIMPLEMENTED);
+		return ISC_R_NOTIMPLEMENTED;
 	}
 
 	dns_name_format(&sdlz->common.origin, origin, sizeof(origin));
@@ -342,11 +342,11 @@ newversion(dns_db_t *db, dns_dbversion_t **versionp) {
 		sdlz_log(ISC_LOG_ERROR,
 			 "sdlz newversion on origin %s failed : %s", origin,
 			 isc_result_totext(result));
-		return (result);
+		return result;
 	}
 
 	sdlz->future_version = *versionp;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static void
@@ -408,7 +408,7 @@ createnode(dns_sdlz_db_t *sdlz, dns_sdlznode_t **nodep) {
 	node->magic = SDLZLOOKUP_MAGIC;
 
 	*nodep = node;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static void
@@ -485,12 +485,12 @@ getnodedata(dns_db_t *db, const dns_name_t *name, bool create,
 		dns_name_getlabelsequence(name, 0, labels, &relname);
 		result = dns_name_totext(&relname, DNS_NAME_OMITFINALDOT, &b);
 		if (result != ISC_R_SUCCESS) {
-			return (result);
+			return result;
 		}
 	} else {
 		result = dns_name_totext(name, DNS_NAME_OMITFINALDOT, &b);
 		if (result != ISC_R_SUCCESS) {
-			return (result);
+			return result;
 		}
 	}
 	isc_buffer_putuint8(&b, 0);
@@ -499,13 +499,13 @@ getnodedata(dns_db_t *db, const dns_name_t *name, bool create,
 	result = dns_name_totext(&sdlz->common.origin, DNS_NAME_OMITFINALDOT,
 				 &b2);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 	isc_buffer_putuint8(&b2, 0);
 
 	result = createnode(sdlz, &node);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 
 	isorigin = dns_name_equal(name, &sdlz->common.origin);
@@ -553,7 +553,7 @@ getnodedata(dns_db_t *db, const dns_name_t *name, bool create,
 					dns_wildcardname, fname, fname, NULL);
 				if (result != ISC_R_SUCCESS) {
 					MAYBE_UNLOCK(sdlz->dlzimp);
-					return (result);
+					return result;
 				}
 				wild = fname;
 			}
@@ -563,7 +563,7 @@ getnodedata(dns_db_t *db, const dns_name_t *name, bool create,
 						 &b);
 			if (result != ISC_R_SUCCESS) {
 				MAYBE_UNLOCK(sdlz->dlzimp);
-				return (result);
+				return result;
 			}
 			isc_buffer_putuint8(&b, 0);
 
@@ -585,7 +585,7 @@ getnodedata(dns_db_t *db, const dns_name_t *name, bool create,
 	if (result != ISC_R_SUCCESS) {
 		isc_refcount_decrementz(&node->references);
 		destroynode(node);
-		return (result);
+		return result;
 	}
 
 	if (isorigin && sdlz->dlzimp->methods->authority != NULL) {
@@ -597,7 +597,7 @@ getnodedata(dns_db_t *db, const dns_name_t *name, bool create,
 		if (result != ISC_R_SUCCESS && result != ISC_R_NOTIMPLEMENTED) {
 			isc_refcount_decrementz(&node->references);
 			destroynode(node);
-			return (result);
+			return result;
 		}
 	}
 
@@ -608,20 +608,20 @@ getnodedata(dns_db_t *db, const dns_name_t *name, bool create,
 	}
 
 	*nodep = node;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
 findnodeext(dns_db_t *db, const dns_name_t *name, bool create,
 	    dns_clientinfomethods_t *methods, dns_clientinfo_t *clientinfo,
 	    dns_dbnode_t **nodep DNS__DB_FLARG) {
-	return (getnodedata(db, name, create, 0, methods, clientinfo, nodep));
+	return getnodedata(db, name, create, 0, methods, clientinfo, nodep);
 }
 
 static isc_result_t
 findnode(dns_db_t *db, const dns_name_t *name, bool create,
 	 dns_dbnode_t **nodep DNS__DB_FLARG) {
-	return (getnodedata(db, name, create, 0, NULL, NULL, nodep));
+	return getnodedata(db, name, create, 0, NULL, NULL, nodep);
 }
 
 static void
@@ -685,20 +685,20 @@ createiterator(dns_db_t *db, unsigned int options,
 	REQUIRE(VALID_SDLZDB(sdlz));
 
 	if (sdlz->dlzimp->methods->allnodes == NULL) {
-		return (ISC_R_NOTIMPLEMENTED);
+		return ISC_R_NOTIMPLEMENTED;
 	}
 
 	if ((options & DNS_DB_NSEC3ONLY) != 0 ||
 	    (options & DNS_DB_NONSEC3) != 0)
 	{
-		return (ISC_R_NOTIMPLEMENTED);
+		return ISC_R_NOTIMPLEMENTED;
 	}
 
 	isc_buffer_init(&b, zonestr, sizeof(zonestr));
 	result = dns_name_totext(&sdlz->common.origin, DNS_NAME_OMITFINALDOT,
 				 &b);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 	isc_buffer_putuint8(&b, 0);
 
@@ -724,7 +724,7 @@ createiterator(dns_db_t *db, unsigned int options,
 	if (result != ISC_R_SUCCESS) {
 		dns_dbiterator_t *iter = &sdlziter->common;
 		dbiterator_destroy(&iter DNS__DB_FILELINE);
-		return (result);
+		return result;
 	}
 
 	if (sdlziter->origin != NULL) {
@@ -734,7 +734,7 @@ createiterator(dns_db_t *db, unsigned int options,
 
 	*iteratorp = (dns_dbiterator_t *)sdlziter;
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -753,7 +753,7 @@ findrdataset(dns_db_t *db, dns_dbnode_t *node, dns_dbversion_t *version,
 	UNUSED(sigrdataset);
 
 	if (type == dns_rdatatype_sig || type == dns_rdatatype_rrsig) {
-		return (ISC_R_NOTIMPLEMENTED);
+		return ISC_R_NOTIMPLEMENTED;
 	}
 
 	list = ISC_LIST_HEAD(sdlznode->lists);
@@ -764,12 +764,12 @@ findrdataset(dns_db_t *db, dns_dbnode_t *node, dns_dbversion_t *version,
 		list = ISC_LIST_NEXT(list, link);
 	}
 	if (list == NULL) {
-		return (ISC_R_NOTFOUND);
+		return ISC_R_NOTFOUND;
 	}
 
 	list_tordataset(list, db, node, rdataset);
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -795,7 +795,7 @@ findext(dns_db_t *db, const dns_name_t *name, dns_dbversion_t *version,
 	UNUSED(sdlz);
 
 	if (!dns_name_issubdomain(name, &db->origin)) {
-		return (DNS_R_NXDOMAIN);
+		return DNS_R_NXDOMAIN;
 	}
 
 	olabels = dns_name_countlabels(&db->origin);
@@ -934,7 +934,7 @@ findext(dns_db_t *db, const dns_name_t *name, dns_dbversion_t *version,
 		detachnode(db, &node DNS__DB_FLARG_PASS);
 	}
 
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -942,8 +942,8 @@ find(dns_db_t *db, const dns_name_t *name, dns_dbversion_t *version,
      dns_rdatatype_t type, unsigned int options, isc_stdtime_t now,
      dns_dbnode_t **nodep, dns_name_t *foundname, dns_rdataset_t *rdataset,
      dns_rdataset_t *sigrdataset DNS__DB_FLARG) {
-	return (findext(db, name, version, type, options, now, nodep, foundname,
-			NULL, NULL, rdataset, sigrdataset DNS__DB_FLARG_PASS));
+	return findext(db, name, version, type, options, now, nodep, foundname,
+		       NULL, NULL, rdataset, sigrdataset DNS__DB_FLARG_PASS);
 }
 
 static isc_result_t
@@ -974,7 +974,7 @@ allrdatasets(dns_db_t *db, dns_dbnode_t *node, dns_dbversion_t *version,
 
 	*iteratorp = (dns_rdatasetiter_t *)iterator;
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -993,7 +993,7 @@ modrdataset(dns_db_t *db, dns_dbnode_t *node, dns_dbversion_t *version,
 	REQUIRE(VALID_SDLZDB(sdlz));
 
 	if (mod_function == NULL) {
-		return (ISC_R_NOTIMPLEMENTED);
+		return ISC_R_NOTIMPLEMENTED;
 	}
 
 	sdlznode = (dns_sdlznode_t *)node;
@@ -1041,7 +1041,7 @@ cleanup:
 		dns_master_styledestroy(&style, mctx);
 	}
 
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -1056,12 +1056,12 @@ addrdataset(dns_db_t *db, dns_dbnode_t *node, dns_dbversion_t *version,
 	REQUIRE(VALID_SDLZDB(sdlz));
 
 	if (sdlz->dlzimp->methods->addrdataset == NULL) {
-		return (ISC_R_NOTIMPLEMENTED);
+		return ISC_R_NOTIMPLEMENTED;
 	}
 
 	result = modrdataset(db, node, version, rdataset, options,
 			     sdlz->dlzimp->methods->addrdataset);
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -1075,12 +1075,12 @@ subtractrdataset(dns_db_t *db, dns_dbnode_t *node, dns_dbversion_t *version,
 	REQUIRE(VALID_SDLZDB(sdlz));
 
 	if (sdlz->dlzimp->methods->subtractrdataset == NULL) {
-		return (ISC_R_NOTIMPLEMENTED);
+		return ISC_R_NOTIMPLEMENTED;
 	}
 
 	result = modrdataset(db, node, version, rdataset, options,
 			     sdlz->dlzimp->methods->subtractrdataset);
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -1097,7 +1097,7 @@ deleterdataset(dns_db_t *db, dns_dbnode_t *node, dns_dbversion_t *version,
 	REQUIRE(VALID_SDLZDB(sdlz));
 
 	if (sdlz->dlzimp->methods->delrdataset == NULL) {
-		return (ISC_R_NOTIMPLEMENTED);
+		return ISC_R_NOTIMPLEMENTED;
 	}
 
 	sdlznode = (dns_sdlznode_t *)node;
@@ -1109,14 +1109,14 @@ deleterdataset(dns_db_t *db, dns_dbnode_t *node, dns_dbversion_t *version,
 		name, b_type, sdlz->dlzimp->driverarg, sdlz->dbdata, version);
 	MAYBE_UNLOCK(sdlz->dlzimp);
 
-	return (result);
+	return result;
 }
 
 static bool
 issecure(dns_db_t *db) {
 	UNUSED(db);
 
-	return (false);
+	return false;
 }
 
 static unsigned int
@@ -1124,7 +1124,7 @@ nodecount(dns_db_t *db, dns_dbtree_t tree) {
 	UNUSED(db);
 	UNUSED(tree);
 
-	return (0);
+	return 0;
 }
 
 static void
@@ -1144,7 +1144,7 @@ getoriginnode(dns_db_t *db, dns_dbnode_t **nodep DNS__DB_FLARG) {
 
 	REQUIRE(VALID_SDLZDB(sdlz));
 	if (sdlz->dlzimp->methods->newversion == NULL) {
-		return (ISC_R_NOTIMPLEMENTED);
+		return ISC_R_NOTIMPLEMENTED;
 	}
 
 	result = getnodedata(db, &sdlz->common.origin, false, 0, NULL, NULL,
@@ -1153,7 +1153,7 @@ getoriginnode(dns_db_t *db, dns_dbnode_t **nodep DNS__DB_FLARG) {
 		sdlz_log(ISC_LOG_ERROR, "sdlz getoriginnode failed: %s",
 			 isc_result_totext(result));
 	}
-	return (result);
+	return result;
 }
 
 static dns_dbmethods_t sdlzdb_methods = {
@@ -1210,9 +1210,9 @@ dbiterator_first(dns_dbiterator_t *iterator DNS__DB_FLARG) {
 
 	sdlziter->current = ISC_LIST_HEAD(sdlziter->nodelist);
 	if (sdlziter->current == NULL) {
-		return (ISC_R_NOMORE);
+		return ISC_R_NOMORE;
 	} else {
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 }
 
@@ -1222,9 +1222,9 @@ dbiterator_last(dns_dbiterator_t *iterator DNS__DB_FLARG) {
 
 	sdlziter->current = ISC_LIST_TAIL(sdlziter->nodelist);
 	if (sdlziter->current == NULL) {
-		return (ISC_R_NOMORE);
+		return ISC_R_NOMORE;
 	} else {
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 }
 
@@ -1236,11 +1236,11 @@ dbiterator_seek(dns_dbiterator_t *iterator,
 	sdlziter->current = ISC_LIST_HEAD(sdlziter->nodelist);
 	while (sdlziter->current != NULL) {
 		if (dns_name_equal(sdlziter->current->name, name)) {
-			return (ISC_R_SUCCESS);
+			return ISC_R_SUCCESS;
 		}
 		sdlziter->current = ISC_LIST_NEXT(sdlziter->current, link);
 	}
-	return (ISC_R_NOTFOUND);
+	return ISC_R_NOTFOUND;
 }
 
 static isc_result_t
@@ -1249,9 +1249,9 @@ dbiterator_prev(dns_dbiterator_t *iterator DNS__DB_FLARG) {
 
 	sdlziter->current = ISC_LIST_PREV(sdlziter->current, link);
 	if (sdlziter->current == NULL) {
-		return (ISC_R_NOMORE);
+		return ISC_R_NOMORE;
 	} else {
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 }
 
@@ -1261,9 +1261,9 @@ dbiterator_next(dns_dbiterator_t *iterator DNS__DB_FLARG) {
 
 	sdlziter->current = ISC_LIST_NEXT(sdlziter->current, link);
 	if (sdlziter->current == NULL) {
-		return (ISC_R_NOMORE);
+		return ISC_R_NOMORE;
 	} else {
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 }
 
@@ -1275,22 +1275,22 @@ dbiterator_current(dns_dbiterator_t *iterator, dns_dbnode_t **nodep,
 	attachnode(iterator->db, sdlziter->current, nodep DNS__DB_FLARG_PASS);
 	if (name != NULL) {
 		dns_name_copy(sdlziter->current->name, name);
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
 dbiterator_pause(dns_dbiterator_t *iterator) {
 	UNUSED(iterator);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
 dbiterator_origin(dns_dbiterator_t *iterator, dns_name_t *name) {
 	UNUSED(iterator);
 	dns_name_copy(dns_rootname, name);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 /*
@@ -1357,7 +1357,6 @@ static isc_result_t
 dns_sdlzcreateDBP(isc_mem_t *mctx, void *driverarg, void *dbdata,
 		  const dns_name_t *name, dns_rdataclass_t rdclass,
 		  dns_db_t **dbp) {
-	isc_result_t result;
 	dns_sdlz_db_t *sdlzdb;
 	dns_sdlzimplementation_t *imp;
 
@@ -1379,10 +1378,7 @@ dns_sdlzcreateDBP(isc_mem_t *mctx, void *driverarg, void *dbdata,
 
 	/* initialize and set origin */
 	dns_name_init(&sdlzdb->common.origin, NULL);
-	result = dns_name_dupwithoffsets(name, mctx, &sdlzdb->common.origin);
-	if (result != ISC_R_SUCCESS) {
-		goto mem_cleanup;
-	}
+	dns_name_dupwithoffsets(name, mctx, &sdlzdb->common.origin);
 
 	isc_refcount_init(&sdlzdb->common.references, 1);
 
@@ -1394,10 +1390,7 @@ dns_sdlzcreateDBP(isc_mem_t *mctx, void *driverarg, void *dbdata,
 	sdlzdb->common.impmagic = SDLZDB_MAGIC;
 	*dbp = (dns_db_t *)sdlzdb;
 
-	return (result);
-mem_cleanup:
-	isc_mem_put(mctx, sdlzdb, sizeof(*sdlzdb));
-	return (result);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -1428,7 +1421,7 @@ dns_sdlzallowzonexfr(void *driverarg, void *dbdata, isc_mem_t *mctx,
 	isc_buffer_init(&b, namestr, sizeof(namestr));
 	result = dns_name_totext(name, DNS_NAME_OMITFINALDOT, &b);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 	isc_buffer_putuint8(&b, 0);
 
@@ -1437,7 +1430,7 @@ dns_sdlzallowzonexfr(void *driverarg, void *dbdata, isc_mem_t *mctx,
 	isc_netaddr_fromsockaddr(&netaddr, clientaddr);
 	result = isc_netaddr_totext(&netaddr, &b2);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 	isc_buffer_putuint8(&b2, 0);
 
@@ -1464,10 +1457,10 @@ dns_sdlzallowzonexfr(void *driverarg, void *dbdata, isc_mem_t *mctx,
 		if (rresult != ISC_R_SUCCESS) {
 			result = rresult;
 		}
-		return (result);
+		return result;
 	}
 
-	return (ISC_R_NOTIMPLEMENTED);
+	return ISC_R_NOTIMPLEMENTED;
 }
 
 static isc_result_t
@@ -1504,7 +1497,7 @@ dns_sdlzcreate(isc_mem_t *mctx, const char *dlzname, unsigned int argc,
 		sdlz_log(ISC_LOG_ERROR, "SDLZ driver failed to load.");
 	}
 
-	return (result);
+	return result;
 }
 
 static void
@@ -1547,7 +1540,7 @@ dns_sdlzfindzone(void *driverarg, void *dbdata, isc_mem_t *mctx,
 	isc_buffer_init(&b, namestr, sizeof(namestr));
 	result = dns_name_totext(name, DNS_NAME_OMITFINALDOT, &b);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 	isc_buffer_putuint8(&b, 0);
 
@@ -1569,7 +1562,7 @@ dns_sdlzfindzone(void *driverarg, void *dbdata, isc_mem_t *mctx,
 					   rdclass, dbp);
 	}
 
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -1592,7 +1585,7 @@ dns_sdlzconfigure(void *driverarg, void *dbdata, dns_view_t *view,
 		result = ISC_R_SUCCESS;
 	}
 
-	return (result);
+	return result;
 }
 
 static bool
@@ -1614,7 +1607,7 @@ dns_sdlzssumatch(const dns_name_t *signer, const dns_name_t *name,
 
 	imp = (dns_sdlzimplementation_t *)driverarg;
 	if (imp->methods->ssumatch == NULL) {
-		return (false);
+		return false;
 	}
 
 	/*
@@ -1655,7 +1648,7 @@ dns_sdlzssumatch(const dns_name_t *signer, const dns_name_t *name,
 				     token_len != 0 ? token_region.base : NULL,
 				     imp->driverarg, dbdata);
 	MAYBE_UNLOCK(imp);
-	return (ret);
+	return ret;
 }
 
 static dns_dlzmethods_t sdlzmethods = { dns_sdlzcreate,	   dns_sdlzdestroy,
@@ -1691,7 +1684,7 @@ dns_sdlz_putrr(dns_sdlzlookup_t *lookup, const char *type, dns_ttl_t ttl,
 	r.length = strlen(type);
 	result = dns_rdatatype_fromtext(&typeval, (void *)&r);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 
 	rdatalist = ISC_LIST_HEAD(lookup->lists);
@@ -1772,7 +1765,7 @@ dns_sdlz_putrr(dns_sdlzlookup_t *lookup, const char *type, dns_ttl_t ttl,
 		isc_lex_destroy(&lex);
 	}
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 failure:
 	if (rdatabuf != NULL) {
@@ -1783,7 +1776,7 @@ failure:
 	}
 	isc_mem_put(mctx, rdata, sizeof(dns_rdata_t));
 
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -1810,7 +1803,7 @@ dns_sdlz_putnamedrr(dns_sdlzallnodes_t *allnodes, const char *name,
 
 	result = dns_name_fromtext(newname, &b, origin, 0, NULL);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 
 	if (allnodes->common.relative_names) {
@@ -1824,7 +1817,7 @@ dns_sdlz_putnamedrr(dns_sdlzallnodes_t *allnodes, const char *name,
 		sdlznode = NULL;
 		result = createnode(sdlz, &sdlznode);
 		if (result != ISC_R_SUCCESS) {
-			return (result);
+			return result;
 		}
 		sdlznode->name = isc_mem_get(mctx, sizeof(dns_name_t));
 		dns_name_init(sdlznode->name, NULL);
@@ -1836,7 +1829,7 @@ dns_sdlz_putnamedrr(dns_sdlzallnodes_t *allnodes, const char *name,
 			allnodes->origin = sdlznode;
 		}
 	}
-	return (dns_sdlz_putrr(sdlznode, type, ttl, data));
+	return dns_sdlz_putrr(sdlznode, type, ttl, data);
 }
 
 isc_result_t
@@ -1852,9 +1845,9 @@ dns_sdlz_putsoa(dns_sdlzlookup_t *lookup, const char *mname, const char *rname,
 		     serial, SDLZ_DEFAULT_REFRESH, SDLZ_DEFAULT_RETRY,
 		     SDLZ_DEFAULT_EXPIRE, SDLZ_DEFAULT_MINIMUM);
 	if (n >= (int)sizeof(str) || n < 0) {
-		return (ISC_R_NOSPACE);
+		return ISC_R_NOSPACE;
 	}
-	return (dns_sdlz_putrr(lookup, "SOA", SDLZ_DEFAULT_TTL, str));
+	return dns_sdlz_putrr(lookup, "SOA", SDLZ_DEFAULT_TTL, str);
 }
 
 isc_result_t
@@ -1918,7 +1911,7 @@ dns_sdlzregister(const char *drivername, const dns_sdlzmethods_t *methods,
 
 	*sdlzimp = imp;
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 cleanup_mutex:
 	/* destroy the driver lock, we don't need it anymore */
@@ -1929,7 +1922,7 @@ cleanup_mutex:
 	 * remove it from the memory context.
 	 */
 	isc_mem_putanddetach(&imp->mctx, imp, sizeof(*imp));
-	return (result);
+	return result;
 }
 
 void
@@ -1968,5 +1961,5 @@ dns_sdlz_setdb(dns_dlzdb_t *dlzdatabase, dns_rdataclass_t rdclass,
 	result = dns_sdlzcreateDBP(dlzdatabase->mctx,
 				   dlzdatabase->implementation->driverarg,
 				   dlzdatabase->dbdata, name, rdclass, dbp);
-	return (result);
+	return result;
 }
