@@ -153,11 +153,13 @@ struct dns_xfrin {
 	atomic_uint nrecs;	     /*%< Number of records recvd */
 	atomic_uint_fast64_t nbytes; /*%< Number of bytes received */
 	_Atomic(isc_time_t) start;   /*%< Start time of the transfer */
+	atomic_uint_fast64_t rate_bytes_per_second;
 	_Atomic(dns_transport_type_t) soa_transport_type;
 	atomic_uint_fast32_t end_serial;
 
 	unsigned int maxrecords; /*%< The maximum number of
 				  *   records set for the zone */
+	uint64_t nbytes_saved;	 /*%< For enforcing the minimum transfer rate */
 
 	dns_tsigkey_t *tsigkey; /*%< Key used to create TSIG */
 	isc_buffer_t *lasttsig; /*%< The last TSIG */
@@ -189,6 +191,7 @@ struct dns_xfrin {
 
 	isc_loop_t *loop;
 
+	isc_timer_t *min_rate_timer;
 	isc_timer_t *max_time_timer;
 	isc_timer_t *max_idle_timer;
 
@@ -198,9 +201,13 @@ struct dns_xfrin {
 #define XFRIN_MAGIC    ISC_MAGIC('X', 'f', 'r', 'I')
 #define VALID_XFRIN(x) ISC_MAGIC_VALID(x, XFRIN_MAGIC)
 
+#define XFRIN_WORK_MAGIC    ISC_MAGIC('X', 'f', 'r', 'W')
+#define VALID_XFRIN_WORK(x) ISC_MAGIC_VALID(x, XFRIN_WORK_MAGIC)
+
 typedef struct xfrin_work {
-	dns_xfrin_t *xfr;
+	unsigned int magic;
 	isc_result_t result;
+	dns_xfrin_t *xfr;
 } xfrin_work_t;
 
 /**************************************************************************/
@@ -261,6 +268,8 @@ xfrin_timedout(void *);
 static void
 xfrin_idledout(void *);
 static void
+xfrin_minratecheck(void *);
+static void
 xfrin_fail(dns_xfrin_t *xfr, isc_result_t result, const char *msg);
 static isc_result_t
 render(dns_message_t *msg, isc_mem_t *mctx, isc_buffer_t *buf);
@@ -293,9 +302,12 @@ axfr_init(dns_xfrin_t *xfr) {
 	CHECK(dns_db_beginload(xfr->db, &xfr->axfr));
 	result = ISC_R_SUCCESS;
 failure:
-	return (result);
+	return result;
 }
 
+static void
+axfr_apply(void *arg);
+
 static isc_result_t
 axfr_putdata(dns_xfrin_t *xfr, dns_diffop_t op, dns_name_t *name, dns_ttl_t ttl,
 	     dns_rdata_t *rdata) {
@@ -304,16 +316,30 @@ axfr_putdata(dns_xfrin_t *xfr, dns_diffop_t op, dns_name_t *name, dns_ttl_t ttl,
 	dns_difftuple_t *tuple = NULL;
 
 	if (rdata->rdclass != xfr->rdclass) {
-		return (DNS_R_BADCLASS);
+		return DNS_R_BADCLASS;
 	}
 
 	CHECK(dns_zone_checknames(xfr->zone, name, rdata));
+
+	if (dns_diff_size(&xfr->diff) > 128 &&
+	    dns_diff_is_boundary(&xfr->diff, name))
+	{
+		xfrin_work_t work = (xfrin_work_t){
+			.magic = XFRIN_WORK_MAGIC,
+			.result = ISC_R_UNSET,
+			.xfr = xfr,
+		};
+		axfr_apply((void *)&work);
+		CHECK(work.result);
+	}
+
 	CHECK(dns_difftuple_create(xfr->diff.mctx, op, name, ttl, rdata,
 				   &tuple));
 	dns_diff_append(&xfr->diff, &tuple);
+
 	result = ISC_R_SUCCESS;
 failure:
-	return (result);
+	return result;
 }
 
 /*
@@ -322,12 +348,14 @@ failure:
 static void
 axfr_apply(void *arg) {
 	xfrin_work_t *work = arg;
+	REQUIRE(VALID_XFRIN_WORK(work));
+
 	dns_xfrin_t *xfr = work->xfr;
+	REQUIRE(VALID_XFRIN(xfr));
+
 	isc_result_t result = ISC_R_SUCCESS;
 	uint64_t records;
 
-	REQUIRE(VALID_XFRIN(xfr));
-
 	if (atomic_load(&xfr->shuttingdown)) {
 		result = ISC_R_SHUTTINGDOWN;
 		goto failure;
@@ -350,6 +378,8 @@ failure:
 static void
 axfr_apply_done(void *arg) {
 	xfrin_work_t *work = arg;
+	REQUIRE(VALID_XFRIN_WORK(work));
+
 	dns_xfrin_t *xfr = work->xfr;
 	isc_result_t result = work->result;
 
@@ -389,8 +419,9 @@ axfr_commit(dns_xfrin_t *xfr) {
 
 	xfrin_work_t *work = isc_mem_get(xfr->mctx, sizeof(*work));
 	*work = (xfrin_work_t){
-		.xfr = dns_xfrin_ref(xfr),
+		.magic = XFRIN_WORK_MAGIC,
 		.result = ISC_R_UNSET,
+		.xfr = dns_xfrin_ref(xfr),
 	};
 	xfr->diff_running = true;
 	isc_work_enqueue(xfr->loop, axfr_apply, axfr_apply_done, work);
@@ -404,7 +435,7 @@ axfr_finalize(dns_xfrin_t *xfr) {
 	result = dns_zone_replacedb(xfr->zone, xfr->db, true);
 	LIBDNS_XFRIN_AXFR_FINALIZE_END(xfr, xfr->info, result);
 
-	return (result);
+	return result;
 }
 
 /**************************************************************************/
@@ -425,7 +456,7 @@ ixfr_init(dns_xfrin_t *xfr) {
 	if (xfr->reqtype != dns_rdatatype_ixfr) {
 		xfrin_log(xfr, ISC_LOG_NOTICE,
 			  "got incremental response to AXFR request");
-		return (DNS_R_FORMERR);
+		return DNS_R_FORMERR;
 	}
 
 	atomic_store(&xfr->is_ixfr, true);
@@ -439,7 +470,7 @@ ixfr_init(dns_xfrin_t *xfr) {
 
 	result = ISC_R_SUCCESS;
 failure:
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -449,7 +480,7 @@ ixfr_putdata(dns_xfrin_t *xfr, dns_diffop_t op, dns_name_t *name, dns_ttl_t ttl,
 	dns_difftuple_t *tuple = NULL;
 
 	if (rdata->rdclass != xfr->rdclass) {
-		return (DNS_R_BADCLASS);
+		return DNS_R_BADCLASS;
 	}
 
 	if (op == DNS_DIFFOP_ADD) {
@@ -460,7 +491,7 @@ ixfr_putdata(dns_xfrin_t *xfr, dns_diffop_t op, dns_name_t *name, dns_ttl_t ttl,
 	dns_diff_append(&xfr->diff, &tuple);
 	result = ISC_R_SUCCESS;
 failure:
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -471,7 +502,7 @@ ixfr_begin_transaction(dns_xfrin_t *xfr) {
 		CHECK(dns_journal_begin_transaction(xfr->ixfr.journal));
 	}
 failure:
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -484,7 +515,7 @@ ixfr_end_transaction(dns_xfrin_t *xfr) {
 		CHECK(dns_journal_commit(xfr->ixfr.journal));
 	}
 failure:
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -508,12 +539,12 @@ ixfr_apply_one(dns_xfrin_t *xfr, ixfr_apply_data_t *data) {
 
 	result = ixfr_end_transaction(xfr);
 
-	return (result);
+	return result;
 failure:
 	/* We need to end the transaction, but keep the previous error */
 	(void)ixfr_end_transaction(xfr);
 
-	return (result);
+	return result;
 }
 
 static void
@@ -523,6 +554,7 @@ ixfr_apply(void *arg) {
 	isc_result_t result = ISC_R_SUCCESS;
 
 	REQUIRE(VALID_XFRIN(xfr));
+	REQUIRE(VALID_XFRIN_WORK(work));
 
 	struct __cds_wfcq_head diff_head;
 	struct cds_wfcq_tail diff_tail;
@@ -560,11 +592,13 @@ ixfr_apply(void *arg) {
 static void
 ixfr_apply_done(void *arg) {
 	xfrin_work_t *work = arg;
-	dns_xfrin_t *xfr = work->xfr;
-	isc_result_t result = work->result;
+	REQUIRE(VALID_XFRIN_WORK(work));
 
+	dns_xfrin_t *xfr = work->xfr;
 	REQUIRE(VALID_XFRIN(xfr));
 
+	isc_result_t result = work->result;
+
 	if (atomic_load(&xfr->shuttingdown)) {
 		result = ISC_R_SHUTTINGDOWN;
 	}
@@ -625,15 +659,16 @@ ixfr_commit(dns_xfrin_t *xfr) {
 	if (!xfr->diff_running) {
 		xfrin_work_t *work = isc_mem_get(xfr->mctx, sizeof(*work));
 		*work = (xfrin_work_t){
-			.xfr = dns_xfrin_ref(xfr),
+			.magic = XFRIN_WORK_MAGIC,
 			.result = ISC_R_UNSET,
+			.xfr = dns_xfrin_ref(xfr),
 		};
 		xfr->diff_running = true;
 		isc_work_enqueue(xfr->loop, ixfr_apply, ixfr_apply_done, work);
 	}
 
 failure:
-	return (result);
+	return result;
 }
 
 /**************************************************************************/
@@ -858,24 +893,22 @@ redo:
 	}
 	result = ISC_R_SUCCESS;
 failure:
-	return (result);
+	return result;
 }
 
-isc_result_t
+void
 dns_xfrin_create(dns_zone_t *zone, dns_rdatatype_t xfrtype,
 		 const isc_sockaddr_t *primaryaddr,
 		 const isc_sockaddr_t *sourceaddr, dns_tsigkey_t *tsigkey,
 		 dns_transport_type_t soa_transport_type,
 		 dns_transport_t *transport, isc_tlsctx_cache_t *tlsctx_cache,
-		 isc_mem_t *mctx, dns_xfrindone_t done, dns_xfrin_t **xfrp) {
+		 isc_mem_t *mctx, dns_xfrin_t **xfrp) {
 	dns_name_t *zonename = dns_zone_getorigin(zone);
 	dns_xfrin_t *xfr = NULL;
-	isc_result_t result;
 	dns_db_t *db = NULL;
 	isc_loop_t *loop = NULL;
 
 	REQUIRE(xfrp != NULL && *xfrp == NULL);
-	REQUIRE(done != NULL);
 	REQUIRE(isc_sockaddr_getport(primaryaddr) != 0);
 	REQUIRE(zone != NULL);
 	REQUIRE(dns_zone_getview(zone) != NULL);
@@ -894,29 +927,29 @@ dns_xfrin_create(dns_zone_t *zone, dns_rdatatype_t xfrtype,
 
 	if (db != NULL) {
 		xfr->zone_had_db = true;
+		dns_db_detach(&db);
 	}
 
-	xfr->done = done;
-
-	/*
-	 * Set *xfrp now, before calling xfrin_start(), otherwise it's
-	 * possible the 'done' callback could be run before *xfrp
-	 * was attached.
-	 */
 	*xfrp = xfr;
+}
+
+isc_result_t
+dns_xfrin_start(dns_xfrin_t *xfr, dns_xfrindone_t done) {
+	isc_result_t result;
+
+	REQUIRE(xfr != NULL);
+	REQUIRE(xfr->zone != NULL);
+	REQUIRE(done != NULL);
+
+	xfr->done = done;
 
 	result = xfrin_start(xfr);
 	if (result != ISC_R_SUCCESS) {
 		xfr->done = NULL;
-		xfrin_fail(xfr, result, "zone transfer setup failed");
-		dns_xfrin_detach(xfrp);
+		xfrin_fail(xfr, result, "zone transfer start failed");
 	}
 
-	if (db != NULL) {
-		dns_db_detach(&db);
-	}
-
-	return (result);
+	return result;
 }
 
 static void
@@ -933,11 +966,37 @@ xfrin_idledout(void *xfr) {
 	xfrin_fail(xfr, ISC_R_TIMEDOUT, "maximum idle time exceeded");
 }
 
+static void
+xfrin_minratecheck(void *arg) {
+	dns_xfrin_t *xfr = arg;
+
+	REQUIRE(VALID_XFRIN(xfr));
+
+	const uint64_t nbytes = atomic_load_relaxed(&xfr->nbytes);
+	const uint64_t min = dns_zone_getminxfrratebytesin(xfr->zone);
+	uint64_t rate = nbytes - xfr->nbytes_saved;
+
+	if (rate < min) {
+		isc_timer_stop(xfr->min_rate_timer);
+		xfrin_fail(xfr, ISC_R_TIMEDOUT,
+			   "minimum transfer rate reached");
+	} else {
+		xfr->nbytes_saved = nbytes;
+
+		/*
+		 * Calculate and store for the statistics channel the transfer
+		 * rate in bytes-per-second for the latest interval.
+		 */
+		rate /= dns_zone_getminxfrratesecondsin(xfr->zone);
+		atomic_store_relaxed(&xfr->rate_bytes_per_second, rate);
+	}
+}
+
 isc_time_t
 dns_xfrin_getstarttime(dns_xfrin_t *xfr) {
 	REQUIRE(VALID_XFRIN(xfr));
 
-	return (atomic_load_relaxed(&xfr->start));
+	return atomic_load_relaxed(&xfr->start);
 }
 
 void
@@ -989,32 +1048,48 @@ uint32_t
 dns_xfrin_getendserial(dns_xfrin_t *xfr) {
 	REQUIRE(VALID_XFRIN(xfr));
 
-	return (atomic_load_relaxed(&xfr->end_serial));
+	return atomic_load_relaxed(&xfr->end_serial);
 }
 
 void
 dns_xfrin_getstats(dns_xfrin_t *xfr, unsigned int *nmsgp, unsigned int *nrecsp,
-		   uint64_t *nbytesp) {
+		   uint64_t *nbytesp, uint64_t *ratep) {
 	REQUIRE(VALID_XFRIN(xfr));
 	REQUIRE(nmsgp != NULL && nrecsp != NULL && nbytesp != NULL);
 
+	uint64_t rate = atomic_load_relaxed(&xfr->rate_bytes_per_second);
+	if (rate == 0) {
+		/*
+		 * Likely the first 'min-transfer-rate-in <bytes> <minutes>'
+		 * minutes interval hasn't passed yet. Calculate the overall
+		 * average transfer rate instead.
+		 */
+		isc_time_t now = isc_time_now();
+		isc_time_t start = atomic_load_relaxed(&xfr->start);
+		uint64_t sec = isc_time_microdiff(&now, &start) / US_PER_SEC;
+		if (sec > 0) {
+			rate = atomic_load_relaxed(&xfr->nbytes) / sec;
+		}
+	}
+
 	SET_IF_NOT_NULL(nmsgp, atomic_load_relaxed(&xfr->nmsg));
 	SET_IF_NOT_NULL(nrecsp, atomic_load_relaxed(&xfr->nrecs));
 	SET_IF_NOT_NULL(nbytesp, atomic_load_relaxed(&xfr->nbytes));
+	SET_IF_NOT_NULL(ratep, rate);
 }
 
 const isc_sockaddr_t *
 dns_xfrin_getsourceaddr(const dns_xfrin_t *xfr) {
 	REQUIRE(VALID_XFRIN(xfr));
 
-	return (&xfr->sourceaddr);
+	return &xfr->sourceaddr;
 }
 
 const isc_sockaddr_t *
 dns_xfrin_getprimaryaddr(const dns_xfrin_t *xfr) {
 	REQUIRE(VALID_XFRIN(xfr));
 
-	return (&xfr->primaryaddr);
+	return &xfr->primaryaddr;
 }
 
 dns_transport_type_t
@@ -1022,17 +1097,17 @@ dns_xfrin_gettransporttype(const dns_xfrin_t *xfr) {
 	REQUIRE(VALID_XFRIN(xfr));
 
 	if (xfr->transport != NULL) {
-		return (dns_transport_get_type(xfr->transport));
+		return dns_transport_get_type(xfr->transport);
 	}
 
-	return (DNS_TRANSPORT_TCP);
+	return DNS_TRANSPORT_TCP;
 }
 
 dns_transport_type_t
 dns_xfrin_getsoatransporttype(dns_xfrin_t *xfr) {
 	REQUIRE(VALID_XFRIN(xfr));
 
-	return (atomic_load_relaxed(&xfr->soa_transport_type));
+	return atomic_load_relaxed(&xfr->soa_transport_type);
 }
 
 const dns_name_t *
@@ -1040,10 +1115,10 @@ dns_xfrin_gettsigkeyname(const dns_xfrin_t *xfr) {
 	REQUIRE(VALID_XFRIN(xfr));
 
 	if (xfr->tsigkey == NULL || xfr->tsigkey->key == NULL) {
-		return (NULL);
+		return NULL;
 	}
 
-	return (dst_key_name(xfr->tsigkey->key));
+	return dst_key_name(xfr->tsigkey->key);
 }
 
 static void
@@ -1052,7 +1127,7 @@ xfrin_shutdown(void *arg) {
 
 	REQUIRE(VALID_XFRIN(xfr));
 
-	xfrin_fail(xfr, ISC_R_CANCELED, "shut down");
+	xfrin_fail(xfr, ISC_R_SHUTTINGDOWN, "shut down");
 	dns_xfrin_detach(&xfr);
 }
 
@@ -1064,7 +1139,7 @@ dns_xfrin_shutdown(dns_xfrin_t *xfr) {
 		dns_xfrin_ref(xfr);
 		isc_async_run(xfr->loop, xfrin_shutdown, xfr);
 	} else {
-		xfrin_fail(xfr, ISC_R_CANCELED, "shut down");
+		xfrin_fail(xfr, ISC_R_SHUTTINGDOWN, "shut down");
 	}
 }
 
@@ -1233,7 +1308,7 @@ xfrin_start(dns_xfrin_t *xfr) {
 	} else {
 		result = dns_dispatch_createtcp(
 			dispmgr, &xfr->sourceaddr, &xfr->primaryaddr,
-			DNS_DISPATCHOPT_UNSHARED, &xfr->disp);
+			xfr->transport, DNS_DISPATCHOPT_UNSHARED, &xfr->disp);
 		dns_dispatchmgr_detach(&dispmgr);
 		if (result != ISC_R_SUCCESS) {
 			goto failure;
@@ -1281,19 +1356,28 @@ xfrin_start(dns_xfrin_t *xfr) {
 	isc_interval_set(&interval, dns_zone_getidlein(xfr->zone), 0);
 	isc_timer_start(xfr->max_idle_timer, isc_timertype_once, &interval);
 
+	/* Set the minimum transfer rate checking timer */
+	if (xfr->min_rate_timer == NULL) {
+		isc_timer_create(dns_zone_getloop(xfr->zone),
+				 xfrin_minratecheck, xfr, &xfr->min_rate_timer);
+	}
+	isc_interval_set(&interval, dns_zone_getminxfrratesecondsin(xfr->zone),
+			 0);
+	isc_timer_start(xfr->min_rate_timer, isc_timertype_ticker, &interval);
+
 	/*
 	 * The connect has to be the last thing that is called before returning,
 	 * as it can end synchronously and destroy the xfr object.
 	 */
 	CHECK(dns_dispatch_connect(xfr->dispentry));
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 failure:
 	xfrin_cancelio(xfr);
 	dns_xfrin_detach(&xfr);
 
-	return (result);
+	return result;
 }
 
 /* XXX the resolver could use this, too */
@@ -1313,7 +1397,7 @@ render(dns_message_t *msg, isc_mem_t *mctx, isc_buffer_t *buf) {
 	result = ISC_R_SUCCESS;
 failure:
 	dns_compress_invalidate(&cctx);
-	return (result);
+	return result;
 }
 
 /*
@@ -1476,10 +1560,10 @@ add_opt(dns_message_t *message, uint16_t udpsize, bool reqnsid,
 	result = dns_message_buildopt(message, &rdataset, 0, udpsize, 0,
 				      ednsopts, count);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 
-	return (dns_message_setopt(message, rdataset));
+	return dns_message_setopt(message, rdataset);
 }
 
 /*
@@ -1561,6 +1645,8 @@ xfrin_send_request(dns_xfrin_t *xfr) {
 	atomic_store_relaxed(&xfr->nbytes, 0);
 	atomic_store_relaxed(&xfr->start, isc_time_now());
 
+	xfr->nbytes_saved = 0;
+
 	msg->id = xfr->id;
 	if (xfr->tsigctx != NULL) {
 		dst_context_destroy(&xfr->tsigctx);
@@ -1597,7 +1683,7 @@ failure:
 		dns_db_closeversion(xfr->db, &ver, false);
 	}
 
-	return (result);
+	return result;
 }
 
 static void
@@ -1679,6 +1765,10 @@ xfrin_end(dns_xfrin_t *xfr, isc_result_t result) {
 		isc_timer_stop(xfr->max_idle_timer);
 		isc_timer_destroy(&xfr->max_idle_timer);
 	}
+	if (xfr->min_rate_timer != NULL) {
+		isc_timer_stop(xfr->min_rate_timer);
+		isc_timer_destroy(&xfr->min_rate_timer);
+	}
 
 	if (xfr->shutdown_result == ISC_R_UNSET) {
 		xfr->shutdown_result = result;
@@ -1959,6 +2049,7 @@ xfrin_recv_done(isc_result_t result, isc_region_t *region, void *arg) {
 	case XFRST_AXFR_END:
 	case XFRST_IXFR_END:
 		/* We are at the end, cancel the timers and IO */
+		isc_timer_stop(xfr->min_rate_timer);
 		isc_timer_stop(xfr->max_idle_timer);
 		isc_timer_stop(xfr->max_time_timer);
 		xfrin_cancelio(xfr);
@@ -1998,6 +2089,8 @@ static void
 xfrin_destroy(dns_xfrin_t *xfr) {
 	uint64_t msecs, persec;
 	isc_time_t now = isc_time_now();
+	char expireopt[sizeof("4000000000")] = { 0 };
+	const char *sep = "";
 
 	REQUIRE(VALID_XFRIN(xfr));
 
@@ -2024,15 +2117,22 @@ xfrin_destroy(dns_xfrin_t *xfr) {
 		msecs = 1;
 	}
 	persec = (atomic_load_relaxed(&xfr->nbytes) * 1000) / msecs;
+
+	if (xfr->expireoptset) {
+		sep = ", expire option ";
+		snprintf(expireopt, sizeof(expireopt), "%u", xfr->expireopt);
+	}
+
 	xfrin_log(xfr, ISC_LOG_INFO,
 		  "Transfer completed: %d messages, %d records, "
 		  "%" PRIu64 " bytes, "
-		  "%u.%03u secs (%u bytes/sec) (serial %" PRIuFAST32 ")",
+		  "%u.%03u secs (%u bytes/sec) (serial %" PRIuFAST32 "%s%s)",
 		  atomic_load_relaxed(&xfr->nmsg),
 		  atomic_load_relaxed(&xfr->nrecs),
 		  atomic_load_relaxed(&xfr->nbytes),
 		  (unsigned int)(msecs / 1000), (unsigned int)(msecs % 1000),
-		  (unsigned int)persec, atomic_load_relaxed(&xfr->end_serial));
+		  (unsigned int)persec, atomic_load_relaxed(&xfr->end_serial),
+		  sep, expireopt);
 
 	/* Cleanup unprocessed IXFR data */
 	struct cds_wfcq_node *node, *next;
@@ -2115,6 +2215,7 @@ xfrin_destroy(dns_xfrin_t *xfr) {
 
 	INSIST(xfr->max_time_timer == NULL);
 	INSIST(xfr->max_idle_timer == NULL);
+	INSIST(xfr->min_rate_timer == NULL);
 
 	isc_loop_detach(&xfr->loop);
 
